pub struct FlatMergeIterator {
algo: MergeAlgo<GenericNode<BoxedRecordBatchIterator>>,
in_progress: BatchBuilder,
output_batch: Option<RecordBatch>,
batch_size: usize,
}Expand description
Iterator to merge multiple sorted iterators into a single sorted iterator.
All iterators must be sorted by primary key, time index, sequence desc.
Fields
algo: MergeAlgo<GenericNode<BoxedRecordBatchIterator>>The merge algorithm to maintain heaps.
in_progress: BatchBuilderCurrent buffered rows to output.
output_batch: Option<RecordBatch>Non-empty batch to output.
batch_size: usizeBatch size to merge rows. This is not a hard limit, the iterator may return smaller batches to avoid concatenating rows.
Implementations
Sourceimpl FlatMergeIterator
impl FlatMergeIterator
Sourcepub fn new(
schema: SchemaRef,
iters: Vec<BoxedRecordBatchIterator>,
batch_size: usize,
) -> Result<Self>
pub fn new( schema: SchemaRef, iters: Vec<BoxedRecordBatchIterator>, batch_size: usize, ) -> Result<Self>
Creates a new iterator to merge sorted iters.
Sourcepub fn next_batch(&mut self) -> Result<Option<RecordBatch>>
pub fn next_batch(&mut self) -> Result<Option<RecordBatch>>
Fetches next sorted batch.
Sourcefn fetch_batch_from_hottest(&mut self) -> Result<()>
fn fetch_batch_from_hottest(&mut self) -> Result<()>
Fetches a batch from the hottest node.
Sourcefn fetch_row_from_hottest(&mut self) -> Result<()>
fn fetch_row_from_hottest(&mut self) -> Result<()>
Fetches a row from the hottest node.
Sourcefn maybe_output_batch(
batch: RecordBatch,
output_batch: &mut Option<RecordBatch>,
)
fn maybe_output_batch( batch: RecordBatch, output_batch: &mut Option<RecordBatch>, )
Adds the batch to the output batch if it is not empty.